pub fn get_global_msgbus_factory_registry() -> &'static MessageBusFactoryRegistryExpand description
Returns the global Python message bus backing factory registry.
pub fn get_global_msgbus_factory_registry() -> &'static MessageBusFactoryRegistryReturns the global Python message bus backing factory registry.